@@ -2,15 +2,19 @@ local_init <- function(
   pipeline = NULL,
   meta = meta_init(),
   names = NULL,
+  shortcut = FALSE,
   queue = "parallel",
-  reporter = "verbose"
+  reporter = "verbose",
+  envir = tar_option_get("envir")
 ) {
   local_new(
     pipeline = pipeline,
     meta = meta,
     names = names,
+    shortcut = shortcut,
     queue = queue,
-    reporter = reporter
+    reporter = reporter,
+    envir = envir
   )
 }
 
@@ -18,15 +22,19 @@ local_new <- function(
   pipeline = NULL,
   meta = NULL,
   names = NULL,
+  shortcut = NULL,
   queue = NULL,
-  reporter = NULL
+  reporter = NULL,
+  envir = NULL
 ) {
   local_class$new(
     pipeline = pipeline,
     meta = meta,
     names = names,
+    shortcut = shortcut,
     queue = queue,
-    reporter = reporter
+    reporter = reporter,
+    envir = envir
   )
 }
 
@@ -36,14 +44,18 @@ local_class <- R6::R6Class(
   portable = FALSE,
   cloneable = FALSE,
   public = list(
-    assert_deployment = function(target) {
+    tar_assert_deployment = function(target) {
     },
     run_target = function(name) {
       target <- pipeline_get_target(self$pipeline, name)
       target_gc(target)
-      self$assert_deployment(target)
+      self$tar_assert_deployment(target)
       target_prepare(target, self$pipeline, self$scheduler)
-      target_run(target = target, envir = tar_option_get("envir"))
+      target_run(
+        target = target,
+        envir = self$envir,
+        path_store = self$meta$get_path_store()
+      )
       target_conclude(
         target,
         self$pipeline,
