@@ -15,7 +15,15 @@ require_clustermq <- function() {
 
 skip_cran <- function() {
   skip_on_cran()
-  if (!identical(Sys.getenv("TAR_ON_CRAN", unset = ""), "true")) {
-    skip("on cran")
+  if (!identical(Sys.getenv("TAR_NOT_CRAN", unset = ""), "true")) {
+    skip("running on cran")
   }
 }
+
+skip_torch <- function() {
+  skip_if_not_installed("torch")
+  tryCatch(
+    torch::torch_zeros(10),
+    error = function(e) skip("torch is not working.")
+  )
+}
